..  _development-community:

##################################
django CMS's development community
##################################

You can join us online:

* in our `django CMS Slack channel <https://www.django-cms.org/slack>`_
* on our `Discourse forum <https://discourse.django-cms.org>`_
* on `StackOverflow <https://stackoverflow.com/questions/tagged/django-cms>`_

You can also follow:

* the `Travis Continuous Integration build reports <https://travis-ci.com/django-cms/django-cms>`_
* the `@djangocms <https://twitter.com/djangocms>`_ Twitter account for general announcements
* the `django CMS Association LinkedIn <https://www.linkedin.com/company/django-cms-association>`_ account

You don't need to be an expert developer to make a valuable contribution - all
you need is a little knowledge of the system, and a willingness to follow the
contribution guidelines.

Remember that contributions to the documentation are highly prized, and key to
the success of the django CMS project.

Development is led by a team of **core developers**, and under the overall
guidance of a **technical board**.

All activity in the community is governed by our :doc:`code_of_conduct`.

**********************
Django CMS Association
**********************

django CMS was released under a BSD licence in 2009. It was created at `Divio AG <https://www.divio.com/>`_
of Zürich, Switzerland, by `Patrick Lauber <https://github.com/digi604/>`_, who led its development for several
years.

In July 2020 Divio handed over the banner to the newly founded
`django CMS Association <https://www.django-cms.org/en/about-us/>`_ (dCA). Its
goal is to drive the success of django CMS, by increasing customer happiness,
market share and open-source-contributions. Divio remains thoroughly committed
to django CMS as the host of the `django CMS project website <https://www.django-cms.org/>`_
and as one of the founding members of the dCA, next to `What <https://what.digital/>`_. and
`Eliga Services <https://eliga.services/>`_.

The dCA’s role in steering the project’s development is formalised in the
`django CMS technical comittee <https://github.com/django-cms/django-cms-mgmt/blob/master/tech-committee/about.md>`_,
whose members are drawn from the django CMS community and the dCA.

The dCA maintains overall control of the `django CMS repository <https://github.com/django-cms/django-cms>`_.
As the chief backer of django CMS, and in order to ensure a consistent and
long-term approach to the project, the dCA reserves the right of final say in
any decisions concerning its development.

As a non-profit organization the django CMS Association is dependent on
donations to fulfill its mission, which is based on the following three statements:

* Innovate and lead
* Foster contribution
* Drive adoption

The best way to donate is to become a member of the association and pay
membership fees. The funding is funneled back into core development and
community projects.

* `Sign up for more information about becoming a member of the dCA <https://www.django-cms.org/en/sign-up/>`_

.. _core_developers:

**********************
The dCA Tech Committee
**********************

Mission
=======

It prepares and updates the technical roadmap for approval by the Executive
Board and/or the General Assembly, manages incoming feature requests and
proposals and takes decisions on awarding credits for work submitted by members.

* `Find out more about the mission <https://github.com/django-cms/django-cms-mgmt/blob/master/tech-committee/about.md#mission>`_

Team
====

* `Overview of the team <https://github.com/django-cms/django-cms-mgmt/blob/master/tech-committee/about.md#team>`_

Tasks
=====

* `Tasks & Decisions Log <https://github.com/django-cms/django-cms-mgmt/blob/master/tech-committee/tasks-and-decisions-log.md>`_
* `Kanban Board <https://github.com/django-cms/django-cms-mgmt/projects/1>`_

Processes
=========

* `Become a core contributor <https://github.com/django-cms/django-cms-mgmt/blob/master/tech-committee/about.md#become-a-core-contributor>`_
* `Become a member of the Tech Committee <https://github.com/django-cms/django-cms-mgmt/blob/master/tech-committee/about.md#become-am-member-of-the-tech-committee>`_
